Local backup and SQL querying of annotation data
=================================================

.. automodule:: histomicstk.annotations_and_masks.annotation_database_parser
    :members:
    :undoc-members:
    :show-inheritance:
